@@ -1,5 +1,6 @@
 from . import geo, occ
 from .__about__ import __gmsh_version__, __version__
+from ._optimize import optimize
 from .helpers import orient_lines, rotation_matrix
 
 __all__ = [
@@ -7,6 +8,7 @@ __all__ = [
     "occ",
     "rotation_matrix",
     "orient_lines",
+    "optimize",
     "__version__",
     "__gmsh_version__",
 ]
