@@ -29,11 +29,11 @@ class Ball:
     def __init__(self, center, radius, angle1=-pi / 2, angle2=pi / 2, angle3=2 * pi):
         self.center = center
         self.radius = radius
-        self._ID = gmsh.model.occ.addSphere(
+        self._id = gmsh.model.occ.addSphere(
             *center, radius, angle1=angle1, angle2=angle2, angle3=angle3
         )
-        self.dim_tag = (3, self._ID)
+        self.dim_tag = (3, self._id)
         self.dim_tags = [self.dim_tag]
 
     def __repr__(self):
-        return f"<pygmsh Ball object (OCC), ID {self._ID}>"
+        return f"<pygmsh Ball object (OCC), ID {self._id}>"
