@@ -30,9 +30,9 @@ class Disk:
         self.radius0 = radius0
         self.radius1 = radius1
 
-        self._ID = gmsh.model.occ.addDisk(*x0, radius0, radius1)
-        self.dim_tag = (self.dim, self._ID)
+        self._id = gmsh.model.occ.addDisk(*x0, radius0, radius1)
+        self.dim_tag = (self.dim, self._id)
         self.dim_tags = [self.dim_tag]
 
     def __repr__(self):
-        return f"<pygmsh Disk object, ID {self._ID}>"
+        return f"<pygmsh Disk object, ID {self._id}>"
