@@ -28,9 +28,9 @@ class Rectangle:
         if corner_radius is None:
             corner_radius = 0.0
 
-        self._ID = gmsh.model.occ.addRectangle(*x0, a, b, roundedRadius=corner_radius)
-        self.dim_tag = (self.dim, self._ID)
+        self._id = gmsh.model.occ.addRectangle(*x0, a, b, roundedRadius=corner_radius)
+        self.dim_tag = (self.dim, self._id)
         self.dim_tags = [self.dim_tag]
 
     def __repr__(self):
-        return f"<pygmsh Rectangle object, ID {self._ID}>"
+        return f"<pygmsh Rectangle object, ID {self._id}>"
